@@ -1,4 +1,7 @@
-from .base import Executor, Hydrator
+from importlib.metadata import version
+
+from .base.executor import Executor
+from .base.hydrator import Hydrator
 from .decorator import hydrator, query, register
 from .mayim import Mayim
 from .sql.mysql.executor import MysqlExecutor
@@ -8,6 +11,8 @@ from .sql.postgres.interface import PostgresPool
 from .sql.sqlite.executor import SQLiteExecutor
 from .sql.sqlite.interface import SQLitePool
 
+__version__ = version("mayim")
+
 __all__ = (
     "hydrator",
     "register",
